@@ -246,9 +246,11 @@ registerAllAccounts()
 uint64_t
 sendAccountTextMessage(const std::string& accountID,
                        const std::string& to,
-                       const std::map<std::string, std::string>& payloads)
+                       const std::map<std::string, std::string>& payloads,
+                       int32_t flags)
 {
-    return jami::Manager::instance().sendTextMessage(accountID, to, payloads);
+    bool onlyConnected = flags & 0x1;
+    return jami::Manager::instance().sendTextMessage(accountID, to, payloads, onlyConnected);
 }
 
 std::vector<Message>
@@ -920,9 +922,8 @@ setCredentials(const std::string& accountID,
 {
     if (auto sipaccount = jami::Manager::instance().getAccount<SIPAccount>(accountID)) {
         sipaccount->doUnregister([&](bool /* transport_free */) {
-            sipaccount->editConfig([&](jami::SipAccountConfig& config){
-                config.setCredentials(details);
-            });
+            sipaccount->editConfig(
+                [&](jami::SipAccountConfig& config) { config.setCredentials(details); });
             sipaccount->loadConfig();
             if (sipaccount->isEnabled())
                 sipaccount->doRegister();
@@ -957,9 +958,9 @@ lookupName(const std::string& account, const std::string& nameserver, const std:
     if (account.empty()) {
         auto cb = [name](const std::string& result, jami::NameDirectory::Response response) {
             jami::emitSignal<libjami::ConfigurationSignal::RegisteredNameFound>("",
-                                                                              (int) response,
-                                                                              result,
-                                                                              name);
+                                                                                (int) response,
+                                                                                result,
+                                                                                name);
         };
         if (nameserver.empty())
             jami::NameDirectory::lookupUri(name, "", cb);
@@ -1023,6 +1024,7 @@ setPushNotificationToken(const std::string& token)
         account->setPushNotificationToken(token);
     }
 }
+
 void
 setPushNotificationTopic(const std::string& topic)
 {
@@ -1031,6 +1033,14 @@ setPushNotificationTopic(const std::string& topic)
     }
 }
 
+void
+setPushNotificationConfig(const std::map<std::string, std::string>& data)
+{
+    for (const auto& account : jami::Manager::instance().getAllAccounts()) {
+        account->setPushNotificationConfig(data);
+    }
+}
+
 void
 pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data)
 {
