@@ -385,7 +385,8 @@ public:
     uint64_t sendTextMessage(const std::string& accountID,
                              const std::string& to,
                              const std::map<std::string, std::string>& payloads,
-                             const bool fromPlugin = false);
+                             bool fromPlugin = false,
+                             bool onlyConnected = false);
 
     int getMessageStatus(uint64_t id) const;
     int getMessageStatus(const std::string& accountID, uint64_t id) const;
